registry-0.1.0.0: the Registry data structure can be used for "assembling components"

Safe HaskellNone
LanguageHaskell2010

Data.Registry

Description

Import this module if you want to access all the functionalities of the Registry API

Documentation